@@ -1,5 +1,5 @@
 ## =============================================================================
-##  PROBLEM measels
+## PROBLEM measels
 ## Models the spread of measels in three equations
 ## U. M. Ascher, R. M. R. Mattheij, and R. D. Russell. Numerical Solution of
 ## Boundary Value Problems for Ordinary Differential Equations. Prentice{Hall,
@@ -9,35 +9,10 @@
 require(bvpSolve)
 
 ## =============================================================================
-## Simple implementation, solved with bvpshoot
+## R implementation
 ## =============================================================================
 
-measel2<-function(t, y, pars, vv)   {
-  bet <- 1575*(1+cos(2*pi*t))
-  dy1 <- mu-bet*y[1]*y[3]
-  dy2 <- bet*y[1]*y[3]-y[2]/lam
-  dy3 <- y[2]/lam-y[3]/vv
-  
-  list(c(dy1, dy2, dy3))
-}
-mu  <- 0.02
-lam <- 0.0279
-v   <- 0.1
-
-guess <- c(0.01, 0.01, 0.01)
-
-res <- function(y, yini, parms, vv) y - yini
-
-Sol <- bvpshoot(fun = measel2, yini=c(y1 = NA, y2 = NA, y3 = NA), yend = res, 
-    x=(0:100)/100, vv = v, guess = rep(0.01,3))
-
-plot(Sol)
-
-## =============================================================================
-## Complex implementation
-## =============================================================================
-
-measel<-function(t, y, pars, vv)  {
+measel <- function(t, y, pars, vv)  {
   bet <- 1575*(1+cos(2*pi*t))
   dy1 <- mu-bet*y[1]*y[3]
   dy2 <- bet*y[1]*y[3]-y[2]/lam
@@ -48,14 +23,8 @@ measel<-function(t, y, pars, vv)  {
   
   list(c(dy1, dy2, dy3, dy4, dy5, dy6))
 }
-mu  <- 0.02
-lam <- 0.0279
-v   <- 0.1
 
-guess <- c(0.01, 0.01, 0.01, 0.01, 0.01, 0.01)
-
-dmeasel<-function(t, y, pars, vv)
-{
+dmeasel <- function(t, y, pars, vv) {
   df <- matrix (data = 0, nrow = 6, ncol = 6)
   bet <- 1575*(1+cos(2*pi*t))
   df[1,1] <-  -bet*y[3]
@@ -75,37 +44,27 @@ bound <- function(i, y, pars,vv) {
   if ( i == 1 | i == 4) return(y[1]-y[4])
   if ( i == 2 | i == 5) return(y[2]-y[5])
   if ( i == 3 | i == 6) return(y[3]-y[6])  
-  }
+}
 
 dbound <- function(i, y, pars,vv) {
   if ( i == 1 | i == 4) return(c(1,0,0,-1,0,0))
   if ( i == 2 | i == 5) return(c(0,1,0,0,-1,0))
   if ( i == 3 | i == 6) return(c(0,0,1,0,0,-1))
-  }
+}
+
+mu  <- 0.02
+lam <- 0.0279
+v   <- 0.1
+x <- seq (0, 1, by = 0.01)
+yguess <- matrix(ncol = length(x), nrow = 6, data = 1)
+rownames(yguess) <- paste("y", 1:6, sep = "")
+
 
 print(system.time(
-sola <- bvpshoot(fun = measel, bound = bound, 
-    x=(0:100)/100, leftbc = 3, vv = v, ncomp = 6)
-))
-
-sol <- bvptwp(fun = measel, bound = bound, 
-    xguess = sola[,1], yguess = t(sola[,-1]),
-    x=(0:100)/100, leftbc = 3,vv = v, ncomp = 6, 
+  solR <- bvptwp(fun = measel, bound = bound, 
+    xguess = x, yguess = yguess,
+    x=x, leftbc = 3, vv = v, ncomp = 6, 
     nmax = 100000, atol = 1e-4)
+))
 
 plot(sol)
-
-print(system.time(
-Sol <- bvpshoot(fun = measel, bound = bound, 
-     jacbound = dbound, jacfunc = dmeasel, 
-      x=(0:100)/100, leftbc = 3, vv = v, ncomp = 6)
-))
-
-print(system.time(
-Sol2 <- bvpshoot(fun = measel, bound = bound, 
-    jacbound = dbound, jacfunc = dmeasel, 
-    x=(0:100)/100, leftbc = 3, vv = v, guess = rep(1, 6))
-))
-
-plot(Sol2)
-
